@@ -283,8 +283,7 @@ class StorageObject:
         @return: iterable
         """
         chunk_size = chunk_size or self.chunk_size
-        return self.client.chunk_download([self.container, self.name],
-            chunk_size=chunk_size)
+        return self.client.chunk_download([self.container, self.name], chunk_size=chunk_size)
     iter_content = chunk_download
     __iter__ = chunk_download
 
@@ -298,11 +297,10 @@ class StorageObject:
         @return: object that responds to o.send('data') to send data
             and o.finish() to finish the upload.
         """
-        chunkable = self.client.chunk_upload([self.container, self.name],
-            size=size, headers=headers)
+        chunkable = self.client.chunk_upload([self.container, self.name], size=size, headers=headers)
         return chunkable
 
-    def send(self, data, check_md5=True, headers=None):
+    def send(self, data, check_md5=True):
         """ Uploads object data
 
         @param data: either a file-like object or a string.
@@ -323,16 +321,14 @@ class StorageObject:
         if isinstance(data, basestring):
             data = StringIO.StringIO(data)
 
-        headers = headers or {}
-        if 'Content-Type' not in headers:
-            content_type = self.content_type
-            if not content_type:
-                _type = None
-                if hasattr(data, 'name'):
-                    _type = mimetypes.guess_type(data.name)[0]
-                content_type = _type or mimetypes.guess_type(self.name)[0] or \
-                    'application/octet-stream'
-            headers['Content-Type'] = content_type
+        headers = {}
+        content_type = self.content_type
+        if not content_type:
+            _type = None
+            if hasattr(data, 'name'):
+                _type = mimetypes.guess_type(data.name)[0]
+            content_type = _type or mimetypes.guess_type(self.name)[0] or 'application/octet-stream'
+        headers['Content-Type'] = content_type
 
         checksum = md5()
         transfered = 0
@@ -421,8 +417,7 @@ class StorageObject:
         return self.make_request('COPY', headers=headers, *args, **kwargs)
 
     def rename(self, new_obj, *args, **kwargs):
-        """ Copies content to a new object existing object and deletes the
-            current object
+        """ Copies content to a new object existing object and deletes the current object
 
         @param new_obj: StorageObject instance to copy data to
         @raises: ResponseError
@@ -433,8 +428,7 @@ class StorageObject:
         def _copy_to(res):
             kwargs['formatter'] = _delete
             return new_obj.copy_from(self, *args, **kwargs)
-        return new_obj.make_request('PUT', headers={'Content-Length': '0'},
-            formatter=_copy_to)
+        return new_obj.make_request('PUT', headers={'Content-Length': '0'}, formatter=_copy_to)
 
     def search(self, q=None, options=None, **kwargs):
         """ Search within path """
@@ -444,12 +438,12 @@ class StorageObject:
 
     def prime_cdn(self, *args, **kwargs):
         """ Prime the object for CDN usage """
-        headers = {'X-Context': 'cdn', 'X-Cdn-Load': True}
+        headers = {'X-Context': 'cdn', 'X-Cdn-Load': 'true'}
         return self.make_request('POST', headers=headers, *args, **kwargs)
 
     def purge_cdn(self, *args, **kwargs):
         """ Purge the object for CDN usage """
-        headers = {'X-Context': 'cdn', 'X-Cdn-Purge': True}
+        headers = {'X-Context': 'cdn', 'X-Cdn-Purge': 'true'}
         return self.make_request('POST', headers=headers, *args, **kwargs)
 
     def make_request(self, method, path=None, *args, **kwargs):
@@ -473,8 +467,7 @@ class StorageObject:
         size = 'Unknown'
         if self.model:
             size = self.model.get('size', 0)
-        return 'StorageObject(%s, %s, %sB)' % (self.container.encode("utf-8"),
-            self.name.encode("utf-8"), size)
+        return 'StorageObject(%s, %s, %sB)' % (self.container.encode("utf-8"), self.name.encode("utf-8"), size)
     __repr__ = __str__
 
     def __enter__(self):
